pub trait ProgressObserver: Send + Sync {
// Required method
fn update(&self, percent: u32, bandwidth: u64, message: &str);
}Expand description
Receives updates concerning the progression of the download, and can display this information to the user, for example using a progress bar. Bandwidth is reported in units of octets per second.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".