Type Definition dash_mpd::fetch::HttpClient
source · pub type HttpClient = Client;Expand description
A Client from the reqwest crate, that we use to download content over HTTP.
pub type HttpClient = Client;A Client from the reqwest crate, that we use to download content over HTTP.