pub struct Binary {
pub signal_type: Option<String>,
pub content: String,
}Expand description
A binary representation of a SCTE 35 cue message.
We don’t attempt to decode these, but the scte35-reader crate is able to parse a subset of the
standard, and the threefive Python library provides a full parser.
Basic messages may just be ‘/’ + base64-encoded string e.g. “/TWFpbiBDb250ZW50” -> “Main Content”
Fields
signal_type: Option<String>content: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for Binary
impl<'de> Deserialize<'de> for Binary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl StructuralPartialEq for Binary