pub struct ContentProtection {Show 14 fields
pub robustness: Option<String>,
pub refId: Option<String>,
pub ref: Option<String>,
pub schemeIdUri: String,
pub value: Option<String>,
pub id: Option<String>,
pub cenc_pssh: Vec<CencPssh>,
pub default_KID: Option<String>,
pub laurl: Option<Laurl>,
pub clearkey_laurl: Option<Laurl>,
pub msprpro: Option<MsprPro>,
pub mspr_is_encrypted: Option<MsprIsEncrypted>,
pub mspr_iv_size: Option<MsprIVSize>,
pub mspr_kid: Option<MsprKid>,
}Expand description
Contains information on DRM (rights management / encryption) mechanisms used in the stream.
If this node is not present, no content protection (such as Widevine and Playready) is applied by the source.
Fields
robustness: Option<String>The robustness level required for this content protection scheme.
refId: Option<String>ref: Option<String>An xs:IDREF that references an identifier in this MPD.
schemeIdUri: StringReferences an identifier in this MPD.
value: Option<String>id: Option<String>cenc_pssh: Vec<CencPssh>The DRM initialization data (Protection System Specific Header).
default_KID: Option<String>The DRM key identifier.
laurl: Option<Laurl>License acquisition URL.
clearkey_laurl: Option<Laurl>License acquisition URL. The name clearkey:Laurl is obsolete and replaced by dashif:laurl. Some manifests in the wild include both, and the parser does not allow for duplicate fields, so we need to allow for this field using a distinct name.
msprpro: Option<MsprPro>Content specific to initialization data using Microsoft PlayReady DRM.
mspr_is_encrypted: Option<MsprIsEncrypted>mspr_iv_size: Option<MsprIVSize>mspr_kid: Option<MsprKid>Trait Implementations
Sourceimpl Clone for ContentProtection
impl Clone for ContentProtection
Sourcefn clone(&self) -> ContentProtection
fn clone(&self) -> ContentProtection
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for ContentProtection
impl Debug for ContentProtection
Sourceimpl Default for ContentProtection
impl Default for ContentProtection
Sourcefn default() -> ContentProtection
fn default() -> ContentProtection
Sourceimpl<'de> Deserialize<'de> for ContentProtectionwhere
ContentProtection: Default,
impl<'de> Deserialize<'de> for ContentProtectionwhere
ContentProtection: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl Hash for ContentProtection
impl Hash for ContentProtection
Sourceimpl PartialEq for ContentProtection
impl PartialEq for ContentProtection
Sourcefn eq(&self, other: &ContentProtection) -> bool
fn eq(&self, other: &ContentProtection) -> bool
self and other values to be equal, and is used by ==.