pub struct MPD {Show 35 fields
pub xmlns: Option<String>,
pub id: Option<String>,
pub profiles: Option<String>,
pub mpdtype: Option<String>,
pub availabilityStartTime: Option<XsDatetime>,
pub availabilityEndTime: Option<XsDatetime>,
pub publishTime: Option<XsDatetime>,
pub mediaPresentationDuration: Option<Duration>,
pub minimumUpdatePeriod: Option<Duration>,
pub minBufferTime: Option<Duration>,
pub timeShiftBufferDepth: Option<Duration>,
pub suggestedPresentationDelay: Option<Duration>,
pub maxSegmentDuration: Option<Duration>,
pub maxSubsegmentDuration: Option<Duration>,
pub xsi: Option<String>,
pub ext: Option<String>,
pub cenc: Option<String>,
pub mspr: Option<String>,
pub xlink: Option<String>,
pub scte35: Option<String>,
pub dvb: Option<String>,
pub schemaLocation: Option<String>,
pub scte214: Option<String>,
pub ProgramInformation: Vec<ProgramInformation>,
pub base_url: Vec<BaseURL>,
pub locations: Vec<Location>,
pub PatchLocation: Vec<PatchLocation>,
pub ServiceDescription: Vec<ServiceDescription>,
pub ContentProtection: Vec<ContentProtection>,
pub periods: Vec<Period>,
pub Metrics: Vec<Metrics>,
pub essential_property: Vec<EssentialProperty>,
pub supplemental_property: Vec<SupplementalProperty>,
pub UTCTiming: Vec<UTCTiming>,
pub LeapSecondInformation: Option<LeapSecondInformation>,
}Expand description
The root node of a parsed DASH MPD manifest.
Fields
xmlns: Option<String>id: Option<String>profiles: Option<String>mpdtype: Option<String>The Presentation Type, either “static” or “dynamic” (a live stream for which segments become available over time).
availabilityStartTime: Option<XsDatetime>availabilityEndTime: Option<XsDatetime>publishTime: Option<XsDatetime>mediaPresentationDuration: Option<Duration>minimumUpdatePeriod: Option<Duration>minBufferTime: Option<Duration>timeShiftBufferDepth: Option<Duration>Prescribes how many seconds of buffer a client should keep to avoid stalling when streaming under ideal network conditions with bandwidth matching the @bandwidth attribute.
suggestedPresentationDelay: Option<Duration>A suggested delay of the presentation compared to the Live edge.
maxSegmentDuration: Option<Duration>maxSubsegmentDuration: Option<Duration>xsi: Option<String>The XML namespace prefix used by convention for the XML Schema Instance namespace.
ext: Option<String>cenc: Option<String>The XML namespace prefix used by convention for the Common Encryption scheme.
mspr: Option<String>The XML namespace prefix used by convention for the Microsoft PlayReady scheme.
xlink: Option<String>The XML namespace prefix used by convention for the XML Linking Language.
scte35: Option<String>The XML namespace prefix used by convention for the “Digital Program Insertion Cueing Message for Cable” (SCTE 35) signaling standard.
dvb: Option<String>The XML namespace prefix used by convention for DASH extensions proposed by the Digital Video Broadcasting Project, as per RFC 5328.
schemaLocation: Option<String>scte214: Option<String>ProgramInformation: Vec<ProgramInformation>base_url: Vec<BaseURL>There may be several BaseURLs, for redundancy (for example multiple CDNs)
locations: Vec<Location>PatchLocation: Vec<PatchLocation>Specifies the location of an MPD “patch document”, a set of instructions for replacing certain parts of the MPD manifest with updated information.
ServiceDescription: Vec<ServiceDescription>ContentProtection: Vec<ContentProtection>periods: Vec<Period>Metrics: Vec<Metrics>essential_property: Vec<EssentialProperty>supplemental_property: Vec<SupplementalProperty>UTCTiming: Vec<UTCTiming>LeapSecondInformation: Option<LeapSecondInformation>Correction for leap seconds, used by the DASH Low Latency specification.